# eric7.Project.ProjectOthersBrowser

Module implementing a class used to display the parts of the project, that don't fit the other categories.

### Global Attributes

None

### Classes

ProjectOthersBrowser | A class used to display the parts of the project, that don't fit the other categories.

### Functions

None

## ProjectOthersBrowser

A class used to display the parts of the project, that don't fit the other categories.

### Signals

showMenu(str, QMenu)
  emitted when a menu is about to be shown. The name of the menu and a reference to the menu are given.

### Derived from

ProjectBaseBrowser

### Class Attributes

None

### Class Methods

None

### Methods

ProjectOthersBrowser | Constructor
__addOthersDirectory | Private method to add files of a directory to the project.
__addOthersFiles | Private method to add files to the project.
__deleteItem | Private method to delete the selected entry from the OTHERS project data area.
__refreshItem | Private slot to refresh (repopulate) an item.
__removeItem | Private slot to remove the selected entry from the OTHERS project data area.
__showContextMenu | Private slot called by the menu aboutToShow signal.
__showContextMenuBack | Private slot called by the backMenu aboutToShow signal.
__showContextMenuDir | Private slot called by the dirMenu aboutToShow signal.
__showContextMenuMulti | Private slot called by the multiMenu aboutToShow signal.
__showMimeType | Private slot to show the mime type of the selected entry.
_contextMenuRequested | Protected slot to show the context menu.
_createPopupMenus | Protected overloaded method to generate the popup menu.
_editPixmap | Protected slot to handle the open in icon editor popup menu entry.
_openFileInEditor | Protected slot to handle the Open in Editor menu action.
_openHexEditor | Protected slot to handle the open in hex editor popup menu entry.
_openItem | Protected slot to handle the open popup menu entry.
_openPdfViewer | Protected slot to handle the open in PDF viewer popup menu entry.
_showContextMenu | Protected slot called before the context menu is shown.
getIcon | Public method to get an icon for the project browser.

### Static Methods

None

#### ProjectOthersBrowser (Constructor)

ProjectOthersBrowser(project, projectBrowser, parent=None)

Constructor

project (Project)
  reference to the project object
projectBrowser (ProjectBrowser)
  reference to the project browser object
parent (QWidget)
  parent widget of this browser

#### ProjectOthersBrowser.__addOthersDirectory

__addOthersDirectory()

Private method to add files of a directory to the project.

#### ProjectOthersBrowser.__addOthersFiles

__addOthersFiles()

Private method to add files to the project.

#### ProjectOthersBrowser.__deleteItem

__deleteItem()

Private method to delete the selected entry from the OTHERS project data area.

#### ProjectOthersBrowser.__refreshItem

__refreshItem()

Private slot to refresh (repopulate) an item.

#### ProjectOthersBrowser.__removeItem

__removeItem()

Private slot to remove the selected entry from the OTHERS project data area.

#### ProjectOthersBrowser.__showContextMenu

__showContextMenu()

Private slot called by the menu aboutToShow signal.

#### ProjectOthersBrowser.__showContextMenuBack

__showContextMenuBack()

Private slot called by the backMenu aboutToShow signal.

#### ProjectOthersBrowser.__showContextMenuDir

__showContextMenuDir()

Private slot called by the dirMenu aboutToShow signal.

#### ProjectOthersBrowser.__showContextMenuMulti

__showContextMenuMulti()

Private slot called by the multiMenu aboutToShow signal.

#### ProjectOthersBrowser.__showMimeType

__showMimeType()

Private slot to show the mime type of the selected entry.

#### ProjectOthersBrowser._contextMenuRequested

_contextMenuRequested(coord)

Protected slot to show the context menu.

coord
  the position of the mouse pointer (QPoint)

#### ProjectOthersBrowser._createPopupMenus

_createPopupMenus()

Protected overloaded method to generate the popup menu.

#### ProjectOthersBrowser._editPixmap

_editPixmap()

Protected slot to handle the open in icon editor popup menu entry.

#### ProjectOthersBrowser._openFileInEditor

_openFileInEditor()

Protected slot to handle the Open in Editor menu action.

#### ProjectOthersBrowser._openHexEditor

_openHexEditor()

Protected slot to handle the open in hex editor popup menu entry.

#### ProjectOthersBrowser._openItem

_openItem()

Protected slot to handle the open popup menu entry.

#### ProjectOthersBrowser._openPdfViewer

_openPdfViewer()

Protected slot to handle the open in PDF viewer popup menu entry.

#### ProjectOthersBrowser._showContextMenu

_showContextMenu(menu)

Protected slot called before the context menu is shown.

It enables/disables the VCS menu entries depending on the overall VCS status and the file status.

menu
  Reference to the popup menu (QPopupMenu)

#### ProjectOthersBrowser.getIcon

getIcon()

Public method to get an icon for the project browser.

Return:
  icon for the browser

Return Type:
  QIcon

Up